@@ -87,7 +87,7 @@ public:
         pluginList = list;
     }
 
-    Qt::ItemFlags flags(const QModelIndex &index) const override
+    Q_REQUIRED_RESULT Qt::ItemFlags flags(const QModelIndex &index) const override
     {
         Qt::ItemFlags flags = QStringListModel::flags(index);
 
@@ -108,29 +108,29 @@ public:
         return flags;
     }
 
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override
+    Q_REQUIRED_RESULT QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override
     {
         Q_UNUSED(parent)
         if (row < 0 || row >= pluginList.count()) {
-            return QModelIndex();
+            return {};
         }
         return createIndex(row, column, pluginList[row]);
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
+    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (!index.isValid() || !index.internalPointer()) {
-            return QVariant();
+            return {};
         }
 
         if (role == Qt::DisplayRole) {
             if (!mNavigator->showText()) {
-                return QVariant();
+                return {};
             }
             return static_cast<KontactInterface::Plugin *>(index.internalPointer())->title();
         } else if (role == Qt::DecorationRole) {
             if (!mNavigator->showIcons()) {
-                return QVariant();
+                return {};
             }
             return QIcon::fromTheme(static_cast<KontactInterface::Plugin *>(index.internalPointer())->icon());
         } else if (role == Qt::TextAlignmentRole) {
@@ -139,7 +139,7 @@ public:
             if (!mNavigator->showText()) {
                 return static_cast<KontactInterface::Plugin *>(index.internalPointer())->title();
             }
-            return QVariant();
+            return {};
         } else if (role == PluginName) {
             return static_cast<KontactInterface::Plugin *>(index.internalPointer())->identifier();
         }
@@ -163,7 +163,7 @@ public:
     }
 
 protected:
-    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override
+    Q_REQUIRED_RESULT bool lessThan(const QModelIndex &left, const QModelIndex &right) const override
     {
         auto leftPlugin = static_cast<KontactInterface::Plugin *>(left.internalPointer());
         auto rightPlugin = static_cast<KontactInterface::Plugin *>(right.internalPointer());
@@ -223,10 +223,10 @@ public:
         painter->restore();
     }
 
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override
+    Q_REQUIRED_RESULT QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override
     {
         if (!index.isValid() || !index.internalPointer()) {
-            return QSize();
+            return {};
         }
 
         QStyleOptionViewItem optionCopy(*static_cast<const QStyleOptionViewItem *>(&option));
@@ -530,9 +530,7 @@ IconSidePane::IconSidePane(KontactInterface::Core *core, QWidget *parent)
     connect(mNavigator, &Navigator::pluginActivated, this, &IconSidePane::pluginSelected);
 }
 
-IconSidePane::~IconSidePane()
-{
-}
+IconSidePane::~IconSidePane() = default;
 
 void IconSidePane::setCurrentPlugin(const QString &plugin)
 {
