@@ -15,7 +15,6 @@
 #include <KontactInterface/Plugin>
 
 class KActionMenu;
-class KPluginInfo;
 class KSqueezedTextLabel;
 class QAction;
 class QFrame;
@@ -28,7 +27,6 @@ using ActionPluginList = QList<QAction *>;
 
 namespace Kontact
 {
-class AboutDialog;
 class SidePaneBase;
 
 class KONTACT_EXPORT MainWindow : public KontactInterface::Core
@@ -40,7 +38,7 @@ public:
     MainWindow();
     ~MainWindow() override;
 
-    PluginList pluginList() const override
+    Q_REQUIRED_RESULT PluginList pluginList() const override
     {
         return mPlugins;
     }
@@ -67,7 +65,6 @@ protected Q_SLOTS:
     void slotQuit();
     void slotNewToolbarConfig();
     void slotShowIntroduction();
-    void showAboutDialog();
     void slotShowStatusMsg(const QString &);
     void activateInitialPluginModule();
     void slotOpenUrl(const QUrl &url);
@@ -126,7 +123,6 @@ private:
     QMap<QString, QPointer<QWidget>> mFocusWidgets;
     QMap<KontactInterface::Plugin *, QAction *> mPluginAction;
 
-    AboutDialog *mAboutDialog = nullptr;
     bool mReallyClose = false;
     int mSaveSideBarWidth = 10;
     QAction *mShowHideAction = nullptr;
